@@ -329,13 +329,13 @@ class StackProfile(base.Profile):
             return {'Error': {'code': ex.code, 'message': six.text_type(ex)}}
 
         spec = {
-            self.ENVIRONMENT: env,
+            self.ENVIRONMENT: env.to_dict(),
             self.FILES: files,
-            self.TEMPLATE: tmpl,
+            self.TEMPLATE: tmpl.to_dict(),
             self.PARAMETERS: dict((k, v) for k, v in stack.parameters.items()
                                   if k.find('OS::', 0) < 0),
             self.TIMEOUT: stack.timeout_mins,
-            self.DISABLE_ROLLBACK: stack.disable_rollback
+            self.DISABLE_ROLLBACK: stack.is_rollback_disabled
         }
         if overrides:
             spec.update(overrides)
