@@ -202,7 +202,7 @@ class TestSchemaBase(base.SenlinTestCase):
                          'spec version 0.5.',
                          six.text_type(ex))
 
-    def test__validate_version_no_version_resitriction(self):
+    def test__validate_version_no_version_restriction(self):
         sot = FakeSchema()
 
         res = sot._validate_version('field', '1.0')
@@ -365,6 +365,8 @@ class TestInteger(base.SenlinTestCase):
         res = sot.to_schema_type(False)
         self.assertEqual(0, res)
 
+        self.assertIsNone(sot.to_schema_type(None))
+
         ex = self.assertRaises(exc.ESchema, sot.to_schema_type, '456L')
         self.assertEqual("The value '456L' is not a valid Integer",
                          six.text_type(ex))
@@ -381,6 +383,8 @@ class TestInteger(base.SenlinTestCase):
         res = sot.resolve(False)
         self.assertEqual(0, res)
 
+        self.assertIsNone(sot.resolve(None))
+
         ex = self.assertRaises(exc.ESchema, sot.resolve, '456L')
         self.assertEqual("The value '456L' is not a valid Integer",
                          six.text_type(ex))
